<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\ContactDesc;
use Illuminate\Http\Request;

class ContactDescController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = ContactDesc::orderByDesc('id')->get();
        return view('admin.contact_desc.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.contact_desc.create');

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'body_ar' => 'required',
            'title_en' => 'required',
            'body_en' => 'required'
        ]);
        $row = new ContactDesc();
        $row['title->ar'] = $request['title_ar'];
        $row['title->en'] = $request['title_en'];
        $row['body->ar'] = $request['body_ar'];
        $row['body->en'] = $request['body_en'];
        $row->save();
        return redirect()->route('contact_desc.index')->with('message', 'تم الاضافه بنجاح');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = ContactDesc::find($id);
        return view('admin.contact_desc.edit', compact('row'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'body_ar' => 'required',
            'title_en' => 'required',
            'body_en' => 'required'
        ]);
        ContactDesc::where('id', $id)->update([
            'title->ar' => $request['title_ar'],
            'title->en' => $request['title_en'],
            'body->ar' => $request['body_ar'],
            'body->en' => $request['body_en'],
        ]);
        return redirect()->route('contact_desc.index')->with('message', 'تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        ContactDesc::destroy($id);
        return redirect()->back()->with('message', 'تم الحذف بنجاح');
    }
}
